@@ -54,7 +54,7 @@ class(out) <- "mefa"
 return(out)}
 
 ### print
-print.mefa <- function(x, ...) {
+print.mefa <- function(x, cutoff=25, ...) {
 	cat("Object of class 'mefa'\n")
 	cat("Call: ")
 	print(x$call)
@@ -68,11 +68,23 @@ print.mefa <- function(x, ...) {
 	cat("Matrix fill: ", round(x$presences/(x$nsamples*x$nspecies),digits=3),
 		"with (", x$presences, " presences)\n")
 	if(any(x$ninds == 0)){
+		if(length(x$ninds == 0) > cutoff){
+		cat("Samples with zero total count [1:",cutoff,"]: \n")
+		print(names(x$ninds)[which(x$ninds == 0)])
+                cat("...\n")
+                } else {
 		cat("Samples with zero total count: \n")
 		print(names(x$ninds)[which(x$ninds == 0)])}
+                }
 	if(any(x$specabund == 0)){
+		if(length(x$specabund == 0) > cutoff){
+		cat("Species with zero total count [1:",cutoff,"]: \n")
+		print(names(x$ninds)[which(x$ninds == 0)])
+                cat("...\n")
+                } else {
 		cat("Species with zero total count: \n")
 		print(names(x$specabund)[which(x$specabund == 0)])}
+                }
 	if(x$attributes == "both")
 		{cat("Both attribute tables are attached: \n")
 		print(x$attrib.matrix)}
